﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Collections.ObjectModel;
using Syncfusion.SfChart.XForms;
using Xamarin.Forms;

namespace Tooltip
{
   
   public class Sample : ContentPage
    {
        public ChartTooltipExt toolTip;
        AbsoluteLayout absLayout;
        StackLayout layout;
        SfChart chart;
        DataModel dataModel = new DataModel();
      
        public Sample()
        {
            absLayout = new AbsoluteLayout();
            absLayout.VerticalOptions = LayoutOptions.FillAndExpand;

            layout = new StackLayout();
            layout.VerticalOptions = LayoutOptions.FillAndExpand;

            chart = new SfChart();
            chart.VerticalOptions = LayoutOptions.FillAndExpand;

            NumericalAxis primaryAxis = new NumericalAxis();
            chart.PrimaryAxis = primaryAxis;

            NumericalAxis secondaryAxis = new NumericalAxis();
            secondaryAxis.Maximum = 75;
            chart.SecondaryAxis = secondaryAxis;


            ScatterSeries series = new ScatterSeries();
            series.ScatterWidth = 30;
            series.ScatterHeight = 30;
            series.ItemsSource = dataModel.DataPoints;
            series.EnableTooltip = true;

            toolTip = new ChartTooltipExt();
            toolTip.ShowLine = false;
            toolTip.MarkerStyle.Color = Color.Transparent;
            chart.ChartBehaviors.Add(toolTip);

            chart.Series.Add(series);

            ListView list = new ListView();
            list.VerticalOptions = LayoutOptions.FillAndExpand;
            list.HeightRequest = 50;
            list.BackgroundColor = Color.White;

            List< string> list1 = new List<string>();

            foreach(var data in dataModel.DataPoints)
            {
                list1.Add((data as ChartDataPoint).XValue.ToString());
            }

            list.ItemsSource = list1;

            list.ItemSelected += List_ItemSelected;

            Image image = new Image();
            image.Source = "icon.png";
            image.HeightRequest = 30;
            image.WidthRequest = 30;
            
            absLayout.Children.Add(chart);
            absLayout.Children.Add(image, new Rectangle(250, 20, 50, 50));
            layout.Children.Add(list);
            layout.Children.Add(absLayout);
            Content = layout;
        }

      
        private void List_ItemSelected(object sender, SelectedItemChangedEventArgs e)
        {
            foreach (var data in dataModel.DataPoints)
            {
                if ((data as ChartDataPoint).XValue.ToString().Equals(e.SelectedItem.ToString()))
                {
                    float pointX = (float)(chart.ValueToPoint(chart.PrimaryAxis, (double)(dataModel.DataPoints.IndexOf(data) + 1)));
                    float pointY = (float)(chart.ValueToPoint(chart.SecondaryAxis, (data as ChartDataPoint).YValue));
                    toolTip.ShowTooltip(pointX, pointY, chart);
                    break;
                }
            }
        }
    }
    public class DataModel
    {
        public ObservableCollection<ChartDataPoint> DataPoints { get; set; }
        public DataModel()
        {
            DataPoints = new ObservableCollection<ChartDataPoint>();
            DataPoints.Add(new ChartDataPoint(1, 45));
            DataPoints.Add(new ChartDataPoint(2, 65));
            DataPoints.Add(new ChartDataPoint(3, 35));
            DataPoints.Add(new ChartDataPoint(4, 45));
            DataPoints.Add(new ChartDataPoint(5, 25));
            DataPoints.Add(new ChartDataPoint(6, 35));
            DataPoints.Add(new ChartDataPoint(7, 30));
            DataPoints.Add(new ChartDataPoint(8, 25));
        }
    }
}
